import requests

__name__ = 'koinim'
__description__ = 'python library for koinim.com api'
__url__ = 'https://github.com/hakancelik96/koinim'
__author_email__ = 'hakancelik96@outlook.com'
__author__ = 'Hakan Çelik'
__version__ = "0.0.1"

class DictToObject(object):
    def __init__(self, d):
        for key, value in d.items():
            if isinstance(value, (list, tuple)):
               setattr(self, key, [DictToObject(x) if isinstance(x, dict) else x for x in value])
            else:
               setattr(self, key, DictToObject(value) if isinstance(value, dict) else value)


class Ltc:

    def __init__(self):
        self.koinim_api = KoinimApi("LTC")
        self.sell = self.koinim_api.sell
        self.buy = self.koinim_api.buy

    def ltc_to_try(self, ltc_amount):
        return ltc_amount * self.sell

    def try_to_ltc(self, try_amount):
        return try_amount / self.buy

    class OrderBook:

        def __init__(self):
            self.order_book_api = OrderBookApi("LTC").dict_to_object

        def bids(self):
            return self.order_book_api.bids

        def asks(self):
            return self.order_book_api.asks


class Btc:

    def __init__(self):
        self.koinim_api = KoinimApi("BTC")
        self.sell = self.koinim_api.sell
        self.buy = self.koinim_api.buy

    def try_to_btc(self, try_amount):
        return try_amount / self.buy

    def btc_to_try(self, btc_amount=0):
        return self.sell * btc_amount


    class OrderBook:

        def __init__(self):
            self.order_book_api = OrderBookApi("BTC").dict_to_object

        def bids(self):
            return self.order_book_api.bids

        def asks(self):
            return self.order_book_api.asks


class KoinimApi:
    """
    The Koinim class provides access to
    information about coins on the koinim.com platform.
    For example btc buying, selling - ltc buying and
    selling cost, review the codes below.
    """

    api_url = "https://koinim.com/api/v1/ticker/{}_TRY/"

    def __init__(self, type):
        if type == type.lower():
            type = type.upper()
        self.r = requests.get(self.api_url.format(type))

    @property
    def buy(self):
        return float(self.r.json()["sell"])

    @property
    def sell(self):
        return float(self.r.json()["buy"])


class OrderBookApi:

    orderbook_api = "https://koinim.com/api/v1/orderbook/{}_TRY/"

    def __init__(self, type):
        if type == type.lower():
            type = type.upper()
        self.r = requests.get(self.orderbook_api.format(type))

    @property
    def dict_to_object(self):
        return DictToObject(self.r.json())
